==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_he.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>סגנון מיקוד</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>חומרת אופנה</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>חומרת יעילה</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>חומרה</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>הצג שמאל</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>הצג עליון</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>הצג מרכז</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>עליון</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>תחתון</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>הישאר מוצג</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>הישאר מוסתר</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>הסתר אוטומטי</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>הגדרות חמקת החולצה</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_he.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>סגנון מיקוד</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>חומרת אופנה</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>חומרת יעילה</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>מצב קלאסיק</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>מצב מרכז</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>חומרה</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>עליון</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>תחתון</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>מצב</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>הישאר מוצג</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>הישאר מוסתר</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>הסתר אוטומטי</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>הגדרות חמקת החולצה</translation>
    </message>
</context>
</TS>
